## Getting Started

## Démarrage Rapide

### 1. Installation

Install the package via pip:

    pip install promethee-selenium

### 2. Initialization

To initialize a new project with the recommended structure, run:

    promethee-selenium init

To view the documentation in your browser:

    promethee-selenium docs

### 1. Installation

Installez le paquet via pip :

    pip install promethee-selenium

### 2. Initialisation

Pour initialiser un nouveau projet avec la structure recommandée, lancez :

    promethee-selenium init

Pour afficher la documentation dans votre navigateur :

    promethee-selenium docs